# Ignori

[![PyPI](https://img.shields.io/pypi/v/ignori)](https://pypi.org/project/ignori/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ignori)
![GitHub License](https://img.shields.io/github/license/egamagz/ignori)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

Generate .gitignore file without leaving the terminal.

![Ignori screenshot](./assets/ignori_screenshoot.png "Ignori Screenshot")
Ignori was built with [Textual](https://github.com/textualize/textual)

## Installation

To install `ignori`, it is recommended to use pip:

```shell
pip install ignori
```

You can install it from source. Clone this repository and use pip to install:

```shell
git clone https://github.com/EGAMAGZ/ignori.git
cd ignori
pip install .
```

## Usage

To start the app, run:

```shell
ignori
```

## Why?

Normally, when I start a project from scratch or the project initialiser does not generate a gitignore file, I have to search for it. With this, the workflow will not be interrupted by having to google it.

## Credits

Created by Gamaliel Garcia / [@EGAMAGZ](https://github.com/EGAMAGZ)

## LICENSE

[MIT License](./LICENSE)
